import {
  max,
  scaleTime,
  scaleLog,
  extent,
  line,
} from 'd3';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';

const xValue = (d) => d.date;
const yValue = (d) => d.deathTotal;

const margin = {
  top: 40,
  right: 20,
  bottom: 80,
  left: 80,
};

export const LineChart = ({ data, width, height }) => {
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  const yScale = scaleLog()
    .domain([1, max(data, yValue)]) // log scale domain cannot start at 0
    .range([innerHeight, 0]);

  const lineGenerator = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  const mostRecentDate = xScale.domain()[1];
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <path d={lineGenerator(data)} />
        <XAxis xScale={xScale} innerWidth={innerWidth} innerHeight={innerHeight} />
        <YAxis yScale={yScale} innerWidth={innerWidth} innerHeight={innerHeight}/>
        <text transform={`translate(${innerWidth/2},0)`} textAnchor='middle'>Coronavirus Global Deaths Over Time</text>
      </g>
    </svg>
  );
};
